Encode and decode VFEI messages.
Encode and decode VFEI messages.
(ambiguous-fields-values-mp AmbigousFieldsValues)Lens for the mp field from a [[AmbigousFieldsValues]] record. See active.vfei/make-ambiguous-fields-values.
Lens for the `mp` field from a [[AmbigousFieldsValues]] record. See [[active.vfei/make-ambiguous-fields-values]].
(ambiguous-fields-values? thing)Is object a AmbigousFieldsValues record? See active.vfei/make-ambiguous-fields-values.
Is object a `AmbigousFieldsValues` record? See [[active.vfei/make-ambiguous-fields-values]].
(array-format-element-format ArrayFormat)Lens for the element-format field from a [[ArrayFormat]] record. See active.vfei/make-array-format.
Lens for the `element-format` field from a [[ArrayFormat]] record. See [[active.vfei/make-array-format]].
(array-format-size ArrayFormat)Lens for the size field from a [[ArrayFormat]] record. See active.vfei/make-array-format.
Lens for the `size` field from a [[ArrayFormat]] record. See [[active.vfei/make-array-format]].
(array-format? thing)Is object a ArrayFormat record? See active.vfei/make-array-format.
Is object a `ArrayFormat` record? See [[active.vfei/make-array-format]].
(data-item->expr di)Convert a data item to a Clojure expression that generates it.
For generating tests.
Convert a data item to a Clojure expression that generates it. For generating tests.
(data-item-format DataItem)Lens for the format field from a [[DataItem]] record. See active.vfei/really-make-data-item.
Lens for the `format` field from a [[DataItem]] record. See [[active.vfei/really-make-data-item]].
(data-item-name DataItem)Lens for the name field from a [[DataItem]] record. See active.vfei/really-make-data-item.
Lens for the `name` field from a [[DataItem]] record. See [[active.vfei/really-make-data-item]].
(data-item-value DataItem)Lens for the value field from a [[DataItem]] record. See active.vfei/really-make-data-item.
Lens for the `value` field from a [[DataItem]] record. See [[active.vfei/really-make-data-item]].
(data-item? thing)Is object a DataItem record? See active.vfei/really-make-data-item.
Is object a `DataItem` record? See [[active.vfei/really-make-data-item]].
(data-items->expr sq)Convert a seq of data items to a Clojure expression that generates it.
For generating tests.
Convert a seq of data items to a Clojure expression that generates it. For generating tests.
(data-items->map items)Convert a list of VFEI data items into a map.
Convert a list of VFEI data items into a map.
(decode-vfei-string s)Decode a VFEI-encoded string.
Decode a VFEI-encoded string.
(format->expr f)Convert a format to a Clojure expression that generates it.
For generating tests.
Convert a format to a Clojure expression that generates it. For generating tests.
(list-format-size ListFormat)Lens for the size field from a [[ListFormat]] record. See active.vfei/make-list-format.
Lens for the `size` field from a [[ListFormat]] record. See [[active.vfei/make-list-format]].
(list-format? thing)Is object a ListFormat record? See active.vfei/make-list-format.
Is object a `ListFormat` record? See [[active.vfei/make-list-format]].
(make-ambiguous-fields-values mp)Values (numbered) of ambiguous fields on one level.
Values (numbered) of ambiguous fields on one level.
(make-array-format element-format size)Make an array format for a VFEI data item.
Make an array format for a VFEI data item.
(make-data-item name format value)Assert that list length matches format.
Assert that list length matches format.
(make-list-format size)Make a list format for a VFEI data item.
Make a list format for a VFEI data item.
(parse-data-item s null-anywhere?)Parse a VFEI data item, returning it and the rest.
Parse a VFEI data item, returning it and the rest.
(parse-data-item-name s)Parse the name of a VFEI data item, returning a pair of the name and the rest.
Parse the name of a VFEI data item, returning a pair of the name and the rest.
(parse-data-item-value format null-anywhere? s)Parse the value of a VFEI data item, given its format, returning it and the rest.
Parse the value of a VFEI data item, given its format, returning it and the rest.
(parse-format-code s)Parse a VFEI format code, returning it and the rest.
Parse a VFEI format code, returning it and the rest.
(parse-size s)Parse the size of a list or array item, returning it and the rest.
Parse the size of a list or array item, returning it and the rest.
(parse-vfei s & [null-anywhere?])Parse a VFEI message, returning a list of data items.
null-anywhere? says whethere null (Systema extension) is allowed anywhere
or just for A, N, D, and lists.
Parse a VFEI message, returning a list of data items. `null-anywhere?` says whethere `null` (Systema extension) is allowed anywhere or just for `A`, `N`, `D`, and lists.
(really-make-data-item name format value)Make a VFEI data item.
Make a VFEI data item.
(value->expr v)Convert a value to a Clojure expression that generates it.
For generating tests.
Convert a value to a Clojure expression that generates it. For generating tests.
(vfei->map v)Recursivley convert the result of parse-vfei to a key-value map.
Warning: This function does not keep the order of the elements in VFEI lists.
Values of ambiguous fields on one level yield a map with numbers as keys and
values of the ambiguous fields as the values to the numbered keys.
Recursivley convert the result of `parse-vfei` to a key-value map. Warning: This function does not keep the order of the elements in VFEI lists. Values of ambiguous fields on one level yield a map with numbers as keys and values of the ambiguous fields as the values to the numbered keys.
(vfei-encode-char c)Encode a character in VFEI format.
Encode a character in VFEI format.
(vfei-encode-string s)Encode a string as a VFEI style, using C-style escapes.
Encode a string as a VFEI style, using C-style escapes.
(zipmap-ambiguous keys vals)Returns a map with the keys mapped to the corresponding vals. Ambigous keys yield a map with numbered values.
Returns a map with the keys mapped to the corresponding vals. Ambigous keys yield a map with numbered values.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |